@@ -147,8 +147,13 @@ def regexsearch(s):
 def globsearch(s):
     csc = builtins.__xonsh_env__.get("CASE_SENSITIVE_COMPLETIONS")
     glob_sorted = builtins.__xonsh_env__.get("GLOB_SORTED")
+    dotglob = builtins.__xonsh_env__.get("DOTGLOB")
     return globpath(
-        s, ignore_case=(not csc), return_empty=True, sort_result=glob_sorted
+        s,
+        ignore_case=(not csc),
+        return_empty=True,
+        sort_result=glob_sorted,
+        include_dotfiles=dotglob,
     )
 
 
@@ -967,6 +972,19 @@ def list_of_strs_or_callables(x):
     return rtn
 
 
+def list_of_list_of_strs_outer_product(x):
+    """Takes an outer product of a list of strings"""
+    lolos = map(ensure_list_of_strs, x)
+    rtn = []
+    for los in itertools.product(*lolos):
+        s = "".join(los)
+        if "*" in s:
+            rtn.extend(builtins.__xonsh_glob__(s))
+        else:
+            rtn.append(builtins.__xonsh_expand_path__(s))
+    return rtn
+
+
 @lazyobject
 def MACRO_FLAG_KINDS():
     return {
@@ -1232,6 +1250,9 @@ def load_builtins(execer=None, ctx=None):
     builtins.__xonsh_all_jobs__ = {}
     builtins.__xonsh_ensure_list_of_strs__ = ensure_list_of_strs
     builtins.__xonsh_list_of_strs_or_callables__ = list_of_strs_or_callables
+    builtins.__xonsh_list_of_list_of_strs_outer_product__ = (
+        list_of_list_of_strs_outer_product
+    )
     builtins.__xonsh_completers__ = xonsh.completers.init.default_completers()
     builtins.__xonsh_call_macro__ = call_macro
     builtins.__xonsh_enter_macro__ = enter_macro
@@ -1311,6 +1332,7 @@ def unload_builtins():
         "__xonsh_all_jobs__",
         "__xonsh_ensure_list_of_strs__",
         "__xonsh_list_of_strs_or_callables__",
+        "__xonsh_list_of_list_of_strs_outer_product__",
         "__xonsh_history__",
     ]
     for name in names:
