@@ -78,7 +78,7 @@ pathlib = _LazyModule.load('pathlib', 'pathlib')
 platform = _LazyModule.load('platform', 'platform')
 functools = _LazyModule.load('functools', 'functools')
 subprocess = _LazyModule.load('subprocess', 'subprocess')
-__version__ = "0.2.2"
+__version__ = "0.2.4"
 
 
 @functools.lru_cache(1)
@@ -374,7 +374,7 @@ def bash_completions(
     lprefix : int
         Length of the prefix to be replaced in the completion.
     """
-    source = _get_bash_completions_source(paths) or set()
+    source = _get_bash_completions_source(paths) or ""
 
     if prefix.startswith("$"):  # do not complete env variables
         return set(), 0
@@ -1062,7 +1062,7 @@ def _path_from_partial_string(inp, pos=None):
         _string = _string + end
     try:
         val = ast.literal_eval(_string)
-    except SyntaxError:
+    except (SyntaxError, ValueError):
         return None
     if isinstance(val, bytes):
         env = builtins.__xonsh_env__
